@@ -1,6 +1,8 @@
 #We use X!Tandem notation for enzymatic digestion:
 #http://thegpm.org/TANDEM/api/pcs.html
-ENZYMES = {'trypsin': '[KR]|{P}', 'lysc': '[K]|', 'None': '|'}
+ENZYMES = {'trypsin': '[KR]|{P}', 'lysc': '[K]|[X]', 'None': '|',
+           'argc': '[R]|[X]', 'gluc': '[E]|[X]', 'aspn': '[X]|[D]',
+           'V8': '[ED]|[X]'}
 
 #masses from: http://www.weddslist.com/ms/tables.html#tm4
 #stored as mass, charge
@@ -26,6 +28,14 @@ RESIDUE_MASSES =  {'G': (57.021464, 0),
                     'W': (186.079313, 0)
                     }
 
+PI_RESIDUE_CHARGE = {'D': (3.65, -1.0),
+                     'E': (4.25, -1.0),
+                     'C': (8.18, -1.0),
+                     'Y': (10.07, -1.0),
+                     'H': (6.00, 1.0),
+                     'K': (10.53, 1.0),
+                     'R': (12.48, 1.0)}
+
 #stored as mass, charge
 MODIFICATION_MASSES = {'h': (1.007825, 0),
                'h2o': (18.010565, 0),
